@@ -4,8 +4,6 @@ import ctypes
 import pyshorteners
 import random
 import time
-sm = "Hello! Enjoy using the Sime library"
-print(sm)
 class SimeLibraryError(Exception):
     pass
 
@@ -38,7 +36,6 @@ def spaces(n: int) -> None:
     except Exception:
         raise SimeLibraryError("Error occurred during adding spaces")
 
-
 def shorten_url(url: str) -> str:
     try:
         s = pyshorteners.Shortener()
